pub struct Message { /* fields omitted */ }
Representation of a message sent to and received from a Tuya device. The Payload is
serialized to and deserialized from JSON. The sequence number, if sent in a command, will
be included in the response to be able to connect command and response. The return code is
only included if the Message is a response from a device.
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.